@@ -122,6 +122,8 @@ def navigation(
         collapsible item in the navigation menu. For top navigation, if you use
         an empty string as a section header, the pages in that section will be
         displayed at the beginning of the menu before the collapsible sections.
+        Section labels support GitHub-flavored Markdown as described in the
+        ``title`` parameter of ``st.Page``.
 
         When you use a string or path as a page-like object, they are
         internally passed to ``st.Page`` and converted to ``StreamlitPage``
@@ -397,6 +399,7 @@ def _navigation(
             p.is_default = page._default
             p.section_header = section_header
             p.url_pathname = page.url_path
+            p.is_hidden = page._visibility == "hidden"
 
     # Inform our page manager about the set of pages we have
     ctx.pages_manager.set_pages(pagehash_to_pageinfo)
