@@ -33,6 +33,7 @@ _LOGGER: Final = logger.get_logger(__name__)
 
 if TYPE_CHECKING:
     from datetime import timedelta
+    from uuid import UUID
 
     from pandas import DataFrame
     from snowflake.connector.cursor import SnowflakeCursor  # type:ignore[import]
@@ -130,14 +131,21 @@ class BaseSnowflakeConnection(BaseConnection["InternalSnowflakeConnection"]):
             # `snowflake-connector-python` library already implements retries for
             # retryable HTTP errors.
             retry=retry_if_exception(
-                lambda e: hasattr(e, "sqlstate")
-                and e.sqlstate == SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED
+                lambda e: (
+                    hasattr(e, "sqlstate")
+                    and e.sqlstate == SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED
+                )
             ),
             wait=wait_fixed(1),
         )
         # `params` must be an explicit parameter (not captured from closure) so that
         # `@st.cache_data` includes it in the cache key.
-        def _query(sql: str, params: Any = None) -> DataFrame:
+        def _query(
+            # Dummy parameter to retain per-instance caching.
+            instance_id: UUID,  # noqa: ARG001
+            sql: str,
+            params: Any = None,
+        ) -> DataFrame:
             cur = self._instance.cursor()
             cur.execute(sql, params=params, **kwargs)
             return cur.fetch_pandas_all()  # type: ignore
@@ -155,7 +163,7 @@ class BaseSnowflakeConnection(BaseConnection["InternalSnowflakeConnection"]):
             ttl=ttl,
         )(_query)
 
-        return _query(sql, params)
+        return _query(self._connection_instance_id, sql, params)
 
     def write_pandas(
         self,
@@ -638,7 +646,7 @@ class SnowflakeConnection(BaseSnowflakeConnection):
         try:
             if len(st_secrets):
                 _LOGGER.info(
-                    "Connect to Snowflake using the Streamlit secret defined under "
+                    "Connecting to Snowflake using the Streamlit secret defined under "
                     "[connections.snowflake]."
                 )
                 conn_kwargs = {**st_secrets, **kwargs}
@@ -647,7 +655,7 @@ class SnowflakeConnection(BaseSnowflakeConnection):
             # Use the default configuration as defined in https://docs.snowflake.com/en/developer-guide/python-connector/python-connector-connect#setting-a-default-connection
             if self._connection_name == "snowflake":
                 _LOGGER.info(
-                    "Connect to Snowflake using the default configuration as defined "
+                    "Connecting to Snowflake using the default configuration as defined "
                     "in https://docs.snowflake.com/en/developer-guide/python-connector/python-connector-connect#setting-a-default-connection"
                 )
                 return snowflake.connector.connect()
