@@ -59,6 +59,7 @@ class ImageMixin:
         output_format: ImageFormatOrAuto = "auto",
         *,
         use_container_width: bool | None = None,
+        link: str | None = None,
     ) -> DeltaGenerator:
         """Display an image or list of images.
 
@@ -151,6 +152,14 @@ class ImageMixin:
                 ``width="stretch"``. For ``use_container_width=False``, use
                 ``width="content"``.
 
+        link : str or None
+            The URL to open when a user clicks on the image. This can be an
+            external URL like ``"https://streamlit.io"`` or a relative path
+            like ``"/my_page"``. If ``link`` is ``None`` (default), the
+            image will not include a hyperlink.
+
+            This parameter is only supported when displaying a single image.
+
         Example
         -------
         >>> import streamlit as st
@@ -213,6 +222,16 @@ class ImageMixin:
             channels,
             output_format,
         )
+
+        if link:
+            # Validate that link is only used with a single image
+            if len(image_list_proto.imgs) > 1:
+                raise StreamlitAPIException(
+                    "The `link` parameter is only supported when displaying a single image. "
+                    f"You passed {len(image_list_proto.imgs)} images."
+                )
+            image_list_proto.link = link
+
         return self.dg._enqueue("imgs", image_list_proto, layout_config=layout_config)
 
     @property
