@@ -315,7 +315,7 @@ def image_to_url(
 
     # Numpy Arrays (ie opencv)
     elif isinstance(image, np.ndarray):
-        image = _clip_image(_verify_np_shape(image), clamp)  # ty: ignore[invalid-argument-type]
+        image = _clip_image(_verify_np_shape(image), clamp)  # ty: ignore[invalid-argument-type, unused-ignore-comment]
 
         if channels == "BGR":
             if len(image.shape) == 3:
@@ -405,7 +405,7 @@ def marshall_images(
     if isinstance(image, (list, set, tuple)):
         images = list(image)
     elif isinstance(image, np.ndarray) and len(image.shape) == 4:
-        images = _4d_to_list_3d(image)  # ty: ignore[invalid-argument-type]
+        images = _4d_to_list_3d(image)  # ty: ignore[invalid-argument-type, unused-ignore-comment]
     else:
         images = cast("Sequence[AtomicImage]", [image])
 
