@@ -43,6 +43,7 @@ from streamlit.proto.TextInput_pb2 import TextInput as TextInputProto
 from streamlit.runtime.metrics_util import gather_metrics
 from streamlit.runtime.scriptrunner import ScriptRunContext, get_script_run_ctx
 from streamlit.runtime.state import (
+    BindOption,
     WidgetArgs,
     WidgetCallback,
     WidgetKwargs,
@@ -60,9 +61,13 @@ if TYPE_CHECKING:
 @dataclass
 class TextInputSerde:
     value: str | None
+    max_chars: int | None = None
 
     def deserialize(self, ui_value: str | None) -> str | None:
-        return ui_value if ui_value is not None else self.value
+        result = ui_value if ui_value is not None else self.value
+        if result is not None and self.max_chars is not None:
+            result = result[: self.max_chars]
+        return result
 
     def serialize(self, v: str | None) -> str | None:
         return v
@@ -71,9 +76,13 @@ class TextInputSerde:
 @dataclass
 class TextAreaSerde:
     value: str | None
+    max_chars: int | None = None
 
     def deserialize(self, ui_value: str | None) -> str | None:
-        return ui_value if ui_value is not None else self.value
+        result = ui_value if ui_value is not None else self.value
+        if result is not None and self.max_chars is not None:
+            result = result[: self.max_chars]
+        return result
 
     def serialize(self, v: str | None) -> str | None:
         return v
@@ -99,6 +108,7 @@ class TextWidgetsMixin:
         label_visibility: LabelVisibility = "visible",
         icon: str | None = None,
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str:
         pass
 
@@ -121,6 +131,7 @@ class TextWidgetsMixin:
         label_visibility: LabelVisibility = "visible",
         icon: str | None = None,
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str | None:
         pass
 
@@ -143,6 +154,7 @@ class TextWidgetsMixin:
         label_visibility: LabelVisibility = "visible",
         icon: str | None = None,
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str | None:
         r"""Display a single-line text input widget.
 
@@ -156,9 +168,9 @@ class TextWidgetsMixin:
             the font height.
 
             Unsupported Markdown elements are unwrapped so only their children
-            (text contents) render. Display unsupported elements as literal
-            characters by backslash-escaping them. E.g.,
-            ``"1\. Not an ordered list"``.
+            (text contents) render. Common block-level Markdown (headings,
+            lists, blockquotes) is automatically escaped and displays as
+            literal text in labels.
 
             See the ``body`` parameter of |st.markdown|_ for additional,
             supported Markdown directives.
@@ -178,10 +190,24 @@ class TextWidgetsMixin:
         max_chars : int or None
             Max number of characters allowed in text input.
 
-        key : str or int
-            An optional string or integer to use as the unique key for the widget.
-            If this is omitted, a key will be generated for the widget
-            based on its content. No two widgets may have the same key.
+        key : str, int, or None
+            An optional string or integer to use as the unique key for
+            the widget. If this is ``None`` (default), a key will be
+            generated for the widget based on the values of the other
+            parameters. No two widgets may have the same key. Assigning
+            a key stabilizes the widget's identity and preserves its
+            state across reruns even when other parameters change.
+
+            .. note::
+               Changing ``max_chars`` resets the widget even when a key
+               is provided.
+
+            A key lets you read or update the widget's value via
+            ``st.session_state[key]``. For more details, see `Widget
+            behavior <https://docs.streamlit.io/develop/concepts/architecture/widget-behavior>`_.
+
+            Additionally, if ``key`` is provided, it will be used as a
+            CSS class name prefixed with ``st-key-``.
 
         type : "default" or "password"
             The type of the text input. This can be either "default" (for
@@ -256,6 +282,24 @@ class TextWidgetsMixin:
               the parent container, the width of the widget matches the width
               of the parent container.
 
+        bind : "query-params" or None
+            Binding mode for syncing the widget's value with a URL query
+            parameter. If this is ``None`` (default), the widget's value
+            is not synced to the URL. When this is set to
+            ``"query-params"``, changes to the widget update the URL, and
+            the widget can be initialized or updated through a query
+            parameter in the URL. This requires ``key`` to be set. The
+            key is used as the query parameter name.
+
+            When the widget's value equals its default, the query
+            parameter is removed from the URL to keep it clean. A bound
+            query parameter can't be set or deleted through
+            ``st.query_params``; it can only be programmatically changed
+            through ``st.session_state``.
+
+            This can't be used with ``type="password"``. An empty
+            query parameter (e.g., ``?my_key=``) clears the widget.
+
         Returns
         -------
         str or None
@@ -291,6 +335,7 @@ class TextWidgetsMixin:
             label_visibility=label_visibility,
             icon=icon,
             width=width,
+            bind=bind,
             ctx=ctx,
         )
 
@@ -312,6 +357,7 @@ class TextWidgetsMixin:
         label_visibility: LabelVisibility = "visible",
         icon: str | None = None,
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
         ctx: ScriptRunContext | None = None,
     ) -> str | None:
         key = to_key(key)
@@ -387,7 +433,18 @@ class TextWidgetsMixin:
             autocomplete = "new-password" if type == "password" else ""
         text_input_proto.autocomplete = autocomplete
 
-        serde = TextInputSerde(value)
+        # Prevent binding password inputs to query params (exposes secrets in URL)
+        if bind == "query-params" and type == "password":
+            raise StreamlitAPIException(
+                "Cannot use `bind='query-params'` with `type='password'`. "
+                "Password values must not appear in URLs."
+            )
+
+        # Set query param key if bound
+        if bind == "query-params" and key is not None:
+            text_input_proto.query_param_key = str(key)
+
+        serde = TextInputSerde(value, max_chars)
 
         widget_state = register_widget(
             text_input_proto.id,
@@ -398,6 +455,9 @@ class TextWidgetsMixin:
             serializer=serde.serialize,
             ctx=ctx,
             value_type="string_value",
+            bind=bind,
+            # Text input is clearable (empty string is a valid value)
+            clearable=True,
         )
 
         if widget_state.value_changed:
@@ -428,6 +488,7 @@ class TextWidgetsMixin:
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str:
         pass
 
@@ -448,6 +509,7 @@ class TextWidgetsMixin:
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str | None:
         pass
 
@@ -468,6 +530,7 @@ class TextWidgetsMixin:
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
     ) -> str | None:
         r"""Display a multi-line text input widget.
 
@@ -481,9 +544,9 @@ class TextWidgetsMixin:
             the font height.
 
             Unsupported Markdown elements are unwrapped so only their children
-            (text contents) render. Display unsupported elements as literal
-            characters by backslash-escaping them. E.g.,
-            ``"1\. Not an ordered list"``.
+            (text contents) render. Common block-level Markdown (headings,
+            lists, blockquotes) is automatically escaped and displays as
+            literal text in labels.
 
             See the ``body`` parameter of |st.markdown|_ for additional,
             supported Markdown directives.
@@ -522,10 +585,24 @@ class TextWidgetsMixin:
         max_chars : int or None
             Maximum number of characters allowed in text area.
 
-        key : str or int
-            An optional string or integer to use as the unique key for the widget.
-            If this is omitted, a key will be generated for the widget
-            based on its content. No two widgets may have the same key.
+        key : str, int, or None
+            An optional string or integer to use as the unique key for
+            the widget. If this is ``None`` (default), a key will be
+            generated for the widget based on the values of the other
+            parameters. No two widgets may have the same key. Assigning
+            a key stabilizes the widget's identity and preserves its
+            state across reruns even when other parameters change.
+
+            .. note::
+               Changing ``max_chars`` resets the widget even when a key
+               is provided.
+
+            A key lets you read or update the widget's value via
+            ``st.session_state[key]``. For more details, see `Widget
+            behavior <https://docs.streamlit.io/develop/concepts/architecture/widget-behavior>`_.
+
+            Additionally, if ``key`` is provided, it will be used as a
+            CSS class name prefixed with ``st-key-``.
 
         help : str or None
             A tooltip that gets displayed next to the widget label. Streamlit
@@ -570,6 +647,24 @@ class TextWidgetsMixin:
               the parent container, the width of the widget matches the width
               of the parent container.
 
+        bind : "query-params" or None
+            Binding mode for syncing the widget's value with a URL query
+            parameter. If this is ``None`` (default), the widget's value
+            is not synced to the URL. When this is set to
+            ``"query-params"``, changes to the widget update the URL, and
+            the widget can be initialized or updated through a query
+            parameter in the URL. This requires ``key`` to be set. The
+            key is used as the query parameter name.
+
+            When the widget's value equals its default, the query
+            parameter is removed from the URL to keep it clean. A bound
+            query parameter can't be set or deleted through
+            ``st.query_params``; it can only be programmatically changed
+            through ``st.session_state``.
+
+            An empty query parameter (e.g., ``?my_key=``) clears the
+            widget.
+
         Returns
         -------
         str or None
@@ -611,6 +706,7 @@ class TextWidgetsMixin:
             disabled=disabled,
             label_visibility=label_visibility,
             width=width,
+            bind=bind,
             ctx=ctx,
         )
 
@@ -630,6 +726,7 @@ class TextWidgetsMixin:
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
         width: WidthWithoutContent = "stretch",
+        bind: BindOption = None,
         ctx: ScriptRunContext | None = None,
     ) -> str | None:
         key = to_key(key)
@@ -684,7 +781,11 @@ class TextWidgetsMixin:
         if placeholder is not None:
             text_area_proto.placeholder = str(placeholder)
 
-        serde = TextAreaSerde(value)
+        # Set query param key if bound
+        if bind == "query-params" and key is not None:
+            text_area_proto.query_param_key = str(key)
+
+        serde = TextAreaSerde(value, max_chars)
         widget_state = register_widget(
             text_area_proto.id,
             on_change_handler=on_change,
@@ -694,6 +795,9 @@ class TextWidgetsMixin:
             serializer=serde.serialize,
             ctx=ctx,
             value_type="string_value",
+            bind=bind,
+            # Text area is clearable (empty string is a valid value)
+            clearable=True,
         )
 
         if widget_state.value_changed:
