@@ -286,6 +286,17 @@ class StreamlitInvalidTextAlignmentError(LocalizableStreamlitException):
         )
 
 
+class StreamlitInvalidBindValueError(LocalizableStreamlitException):
+    """Exception raised when an invalid value is specified for the bind parameter."""
+
+    def __init__(self, bind_value: Any) -> None:
+        super().__init__(
+            'Invalid `bind` value: "{bind_value}". '
+            'Supported values are: `"query-params"` or `None`.',
+            bind_value=bind_value,
+        )
+
+
 # st.multiselect
 class StreamlitSelectionCountExceedsMaxError(LocalizableStreamlitException):
     """Exception raised when there are more default selections specified than the max allowable selections."""
@@ -309,6 +320,30 @@ class StreamlitSelectionCountExceedsMaxError(LocalizableStreamlitException):
         )
 
 
+class StreamlitInvalidMaxError(LocalizableStreamlitException):
+    """Exception raised when an invalid max value is provided (e.g. zero or negative)."""
+
+    def __init__(
+        self,
+        widget_name: str,
+        parameter_name: str,
+        value: int,
+        corrective_action: str | None = None,
+    ) -> None:
+        message = (
+            "In `{widget_name}`, `{parameter_name}` was set to {value}. "
+            "`{parameter_name}` must be a positive integer."
+        )
+        if corrective_action:
+            message += " " + corrective_action
+        super().__init__(
+            message,
+            widget_name=widget_name,
+            parameter_name=parameter_name,
+            value=value,
+        )
+
+
 # st.number_input
 class StreamlitMixedNumericTypesError(LocalizableStreamlitException):
     """Exception raised mixing floats and ints in st.number_input."""
