@@ -908,9 +908,12 @@ class AppSession:
         The heartbeat indicates the frontend is active and keeps the
         websocket from going idle and disconnecting.
 
-        The actual handler here is a noop
-
+        We respond with a heartbeat_ack so the frontend can verify the
+        connection is healthy and detect network issues.
         """
+        msg = ForwardMsg()
+        msg.heartbeat_ack = True
+        self._enqueue_forward_msg(msg)
 
     def _handle_set_run_on_save_request(self, new_value: bool) -> None:
         """Change our run_on_save flag to the given value.
@@ -1129,10 +1132,9 @@ def _populate_theme_msg(msg: CustomThemeConfig, section: str = "theme") -> None:
         ):
             setattr(msg, to_snake_case(option_name), option_val)
 
-    # NOTE: If unset, base and font will default to the protobuf enum zero
-    # values, which are BaseTheme.LIGHT and FontFamily.SANS_SERIF,
-    # respectively. This is why we both don't handle the cases explicitly and
-    # also only log a warning when receiving invalid base/font options.
+    # NOTE: If unset, base will default to the protobuf enum zero value,
+    # which is BaseTheme.LIGHT. This is why we don't handle the case
+    # explicitly and also only log a warning when receiving invalid base options.
     base_map = {
         "light": msg.BaseTheme.LIGHT,
         "dark": msg.BaseTheme.DARK,
@@ -1177,9 +1179,16 @@ def _populate_theme_msg(msg: CustomThemeConfig, section: str = "theme") -> None:
     if font_faces is not None:
         for font_face in font_faces:
             try:
-                if "weight" in font_face:
-                    font_face["weight_range"] = str(font_face["weight"])
-                    del font_face["weight"]
+                if isinstance(font_face, dict):
+                    # Backwards compatibility: accept legacy "weight" or numeric "weight_range".
+                    if "weight" in font_face:
+                        if "weight_range" not in font_face:
+                            font_face["weight_range"] = font_face["weight"]
+                        del font_face["weight"]
+                    if "weight_range" in font_face and not isinstance(
+                        font_face["weight_range"], str
+                    ):
+                        font_face["weight_range"] = str(font_face["weight_range"])
                 msg.font_faces.append(ParseDict(font_face, FontFace()))
             except Exception as e:  # noqa: PERF203
                 _LOGGER.warning(
