@@ -17,6 +17,7 @@ from __future__ import annotations
 import math
 from collections.abc import Iterable, Iterator, Mapping, MutableMapping
 from dataclasses import dataclass, field
+from datetime import date, datetime, time, timedelta, timezone
 from typing import TYPE_CHECKING, Any, Final, cast
 from urllib import parse
 
@@ -54,6 +55,97 @@ class WidgetBinding:
     script_hash: str  # For MPA: identifies main vs page script
 
 
+def _to_non_empty_list(value: str | list[str]) -> list[str]:
+    """Convert URL param value to list, filtering out empty strings.
+
+    Empty strings are reserved to represent "cleared/empty" state, so they
+    are not valid as individual array elements.
+    """
+    parts = list(value) if isinstance(value, list) else [value]
+    return [p for p in parts if p != ""]
+
+
+def is_empty_url_value(value: str | list[str]) -> bool:
+    """Check if URL value represents an empty parameter (e.g., ?foo= with no value).
+
+    Parameters
+    ----------
+    value : str | list[str]
+        The URL parameter value(s).
+
+    Returns
+    -------
+    bool
+        True if all values are empty strings ("" or [""] or ["", ""], etc.).
+        Returns False for mixed values like ["a", ""] which contain valid data.
+    """
+    if isinstance(value, list):
+        return len(value) > 0 and all(v == "" for v in value)
+    return value == ""
+
+
+_UTC_EPOCH: Final = datetime(1970, 1, 1, tzinfo=timezone.utc)
+_SECONDS_TO_MICROS: Final = 1000 * 1000
+_DAYS_TO_MICROS: Final = 24 * 60 * 60 * _SECONDS_TO_MICROS
+
+# Base date for time values must match slider.py's _time_to_datetime.
+_TIME_BASE_DATE: Final = date(2000, 1, 1)
+
+
+def _delta_to_micros(delta: timedelta) -> int:
+    # Uses component-based calculation instead of int(delta.total_seconds() * 1e6)
+    # to avoid floating-point precision loss on large timedeltas.
+    return (
+        delta.microseconds
+        + delta.seconds * _SECONDS_TO_MICROS
+        + delta.days * _DAYS_TO_MICROS
+    )
+
+
+def _try_parse_iso_to_micros(s: str) -> float | None:
+    """Try to parse an ISO date/time/datetime string to microsecond timestamp.
+
+    Supports the same ISO formats used by date/time slider URL parameters:
+    - DATE: ``YYYY-MM-DD``
+    - TIME: ``HH:MM`` or ``HH:MM:SS``
+    - DATETIME: ``YYYY-MM-DDTHH:MM`` or ``YYYY-MM-DDTHH:MM:SS``
+
+    Returns the microsecond float if parsing succeeds, or ``None`` if the
+    string doesn't match any recognized format.
+    """
+    # Try datetime first (contains 'T' separator)
+    if "T" in s:
+        try:
+            dt = datetime.fromisoformat(s)
+            if dt.tzinfo is not None:
+                return None
+            return float(_delta_to_micros(dt.replace(tzinfo=timezone.utc) - _UTC_EPOCH))
+        except ValueError:
+            return None
+
+    # Try date (contains '-')
+    if "-" in s:
+        try:
+            d = date.fromisoformat(s)
+            dt = datetime.combine(d, time(), tzinfo=timezone.utc)
+            return float(_delta_to_micros(dt - _UTC_EPOCH))
+        except ValueError:
+            return None
+
+    # Try time (contains ':')
+    if ":" in s:
+        try:
+            t = time.fromisoformat(s)
+            if t.tzinfo is not None:
+                return None
+            dt = datetime.combine(_TIME_BASE_DATE, t, tzinfo=timezone.utc)
+            return float(_delta_to_micros(dt - _UTC_EPOCH))
+        except ValueError:
+            return None
+
+    return None
+
+
 def parse_url_param(value: str | list[str], value_type: str) -> Any:
     """Convert URL param to Python value based on WidgetState value type.
 
@@ -68,6 +160,10 @@ def parse_url_param(value: str | list[str], value_type: str) -> Any:
     -------
     Any
         The parsed Python value appropriate for the widget type.
+        For empty URL params (e.g., ?foo=):
+        - Array types return []
+        - string_value returns "" (empty string is valid)
+        - Other types return None (signaling "cleared" state)
 
     Raises
     ------
@@ -77,6 +173,17 @@ def parse_url_param(value: str | list[str], value_type: str) -> Any:
     # For single-value types, get the last value if it's a list
     val = value[-1] if isinstance(value, list) else value
 
+    # Handle empty string values (e.g., ?foo= in URL)
+    if is_empty_url_value(value):
+        match value_type:
+            case "string_array_value" | "int_array_value" | "double_array_value":
+                return []  # Empty array
+            case "string_value":
+                return ""  # Empty string is a valid value for text inputs
+            case _:
+                # For other types (bool, int, double), empty signals "cleared"
+                return None
+
     match value_type:
         case "bool_value":
             lower_val = val.lower()
@@ -101,28 +208,33 @@ def parse_url_param(value: str | list[str], value_type: str) -> Any:
             return val
         case "string_array_value":
             # Repeated params: ?foo=a&foo=b -> ["a", "b"]
-            return list(value) if isinstance(value, list) else [value]
+            # Note: Empty strings are filtered - "" is reserved for "cleared/empty" state
+            return _to_non_empty_list(value)
         case "double_array_value":
             # Repeated params: ?foo=1.5&foo=2.5 -> [1.5, 2.5]
-            # Also handles string values for select_slider option matching
-            parts = list(value) if isinstance(value, list) else [value]
+            # Strings kept for select_slider option matching; empty strings filtered
             result_double: list[float | str] = []
-            for part in parts:
+            for part in _to_non_empty_list(value):
                 try:
                     result_double.append(float(part))
                 except ValueError:  # noqa: PERF203
-                    result_double.append(part)  # Keep as string for select_slider
+                    # Try ISO date/time/datetime parsing for date/time sliders.
+                    # Converts human-readable ISO strings to microsecond floats.
+                    micros = _try_parse_iso_to_micros(part)
+                    if micros is not None:
+                        result_double.append(micros)
+                    else:
+                        result_double.append(part)
             return result_double
         case "int_array_value":
             # Repeated params: ?foo=1&foo=2 -> [1, 2]
-            # Also handles string values for option matching (pills, etc.)
-            parts = list(value) if isinstance(value, list) else [value]
+            # Strings kept for option matching (pills, etc.); empty strings filtered
             result_int: list[int | str] = []
-            for part in parts:
+            for part in _to_non_empty_list(value):
                 try:
                     result_int.append(int(part))
                 except ValueError:  # noqa: PERF203
-                    result_int.append(part)  # Keep as string
+                    result_int.append(part)
             return result_int
         case _:
             # Unknown type, return as-is
@@ -201,7 +313,7 @@ class QueryParams(MutableMapping[str, str]):
         except KeyError:
             raise KeyError(missing_key_error_message(key))
 
-    def update(  # ty: ignore[invalid-method-override]
+    def update(
         self,
         other: Iterable[tuple[str, str | Iterable[str]]]
         | SupportsKeysAndGetItem[str, str | Iterable[str]] = (),
