@@ -46,7 +46,11 @@ from streamlit.runtime.state.common import (
     is_keyed_element_id,
 )
 from streamlit.runtime.state.presentation import apply_presenter
-from streamlit.runtime.state.query_params import QueryParams, parse_url_param
+from streamlit.runtime.state.query_params import (
+    QueryParams,
+    is_empty_url_value,
+    parse_url_param,
+)
 from streamlit.runtime.stats import (
     CACHE_MEMORY_FAMILY,
     CacheStat,
@@ -66,6 +70,45 @@ SCRIPT_RUN_WITHOUT_ERRORS_KEY: Final = (
 )
 
 
+def _sanitize_url_array(
+    parsed: list[str],
+    *,
+    valid_options: list[str] | None,
+    max_length: int | None,
+    allow_duplicates: bool = False,
+) -> list[str] | None:
+    """Sanitize a URL-parsed string array by filtering invalid values,
+    optionally removing duplicates, and enforcing a maximum length.
+
+    Returns the sanitized list if any changes were made, or None if the
+    input required no sanitization.
+    """
+    result = parsed
+
+    # Remove values not in the valid options list.
+    if valid_options is not None:
+        result = [v for v in result if v in valid_options]
+
+    # Deduplicate while preserving order. Skipped when allow_duplicates is
+    # True (e.g., select_slider range mode where ?color=red&color=red is a
+    # valid zero-width range).
+    if not allow_duplicates:
+        seen: set[str] = set()
+        deduped: list[str] = []
+        for v in result:
+            if v not in seen:
+                seen.add(v)
+                deduped.append(v)
+        if len(deduped) < len(result):
+            result = deduped
+
+    # Truncate to max_length (e.g. multiselect max_selections).
+    if max_length is not None and max_length > 0 and len(result) > max_length:
+        result = result[:max_length]
+
+    return result if result != parsed else None
+
+
 @dataclass(frozen=True)
 class Serialized:
     """A widget value that's serialized to a protobuf. Immutable."""
@@ -1003,26 +1046,81 @@ class SessionState:
         """Parse URL value, seed widget state, and auto-correct URL if needed.
 
         This method:
-        1. Parses the raw URL string using the widget's value_type
-        2. Deserializes to the widget's native value format
-        3. Handles invalid values (clears URL param, returns False)
-        4. Stores valid values in both widget state and session state
-        5. Auto-corrects the URL if the value was clamped/filtered
+        1. Checks if the URL value is empty and handles based on clearable
+        2. Parses the raw URL string using the widget's value_type
+        3. Deserializes to the widget's native value format
+        4. Handles invalid values (clears URL param, returns False)
+        5. Stores valid values in both widget state and session state
+        6. Auto-corrects the URL if the value was clamped/filtered
 
         Returns True if seeding succeeded, False if the URL value was invalid.
         """
+        # Check if URL value is empty (e.g., ?foo= with no value)
+        if is_empty_url_value(url_value) and not metadata.clearable:
+            # Widget doesn't allow empty state - clear the invalid param
+            self._clear_url_param(user_key)
+            return False
+
         try:
             parsed_value = parse_url_param(url_value, metadata.value_type)
             deserialized_value = metadata.deserializer(parsed_value)
+            default_value = metadata.deserializer(None)
 
-            # Handle case where all URL values were invalid (filtered to empty list)
-            if isinstance(deserialized_value, list) and len(deserialized_value) == 0:
-                url_had_values = (
-                    isinstance(parsed_value, list) and len(parsed_value) > 0
-                ) or (isinstance(parsed_value, str) and len(parsed_value) > 0)
-                if url_had_values:
-                    self._clear_url_param(user_key)
-                    return False
+            # If the deserialized value equals the default, clear the param.
+            # Default values should not be kept in the URL — this matches the
+            # frontend's shouldClearUrlParam behavior. This handles:
+            # 1. Valid input that equals the default (e.g., ?dark_mode=FALSE)
+            # 2. Invalid input that the deserializer rejected and fell back to default
+            # 3. Valid input that normalized to match the default (e.g., "000000" -> "#000000")
+            if deserialized_value == default_value:
+                self._clear_url_param(user_key)
+                return False
+
+            # Handle case where all URL values were invalid (filtered to empty list).
+            # For array types, parsed_value is always a list. If it had values that
+            # were all filtered by the deserializer (e.g., invalid options), clear URL.
+            if (
+                isinstance(deserialized_value, list)
+                and len(deserialized_value) == 0
+                and parsed_value  # Non-empty list means URL had values
+            ):
+                self._clear_url_param(user_key)
+                return False
+
+            # For string_value selection widgets (radio, selectbox), validate
+            # that the parsed URL value is a known option. The deserializer
+            # passes unknown options through as-is (needed for dynamic option
+            # changes and accept_new_options), so we check here instead.
+            # Widgets opt in by passing formatted_options to register_widget.
+            if (
+                metadata.formatted_options is not None
+                and metadata.value_type == "string_value"
+                and isinstance(parsed_value, str)
+                and parsed_value not in metadata.formatted_options
+            ):
+                self._clear_url_param(user_key)
+                return False
+
+            # For string_array_value widgets (e.g. multiselect, select_slider),
+            # sanitize the parsed URL values: filter invalid options, optionally
+            # deduplicate, and enforce max length.
+            if metadata.value_type == "string_array_value" and isinstance(
+                parsed_value, list
+            ):
+                sanitized = _sanitize_url_array(
+                    parsed_value,
+                    valid_options=metadata.formatted_options,
+                    max_length=metadata.max_array_length,
+                    allow_duplicates=metadata.allow_url_duplicates,
+                )
+                if sanitized is not None:
+                    if not sanitized:
+                        self._clear_url_param(user_key)
+                        return False
+                    deserialized_value = metadata.deserializer(sanitized)
+                    if deserialized_value == default_value:
+                        self._clear_url_param(user_key)
+                        return False
 
             # Store the value in widget and session state
             self._new_widget_state.set_from_value(widget_id, deserialized_value)
@@ -1054,56 +1152,13 @@ class SessionState:
         parsed_value: Any,
         deserialized_value: Any,
     ) -> None:
-        """Auto-correct URL if the value was clamped or filtered.
-
-        For selection widgets using human-readable strings in URLs, we preserve
-        the original strings unless values were actually filtered out.
-        """
+        """Auto-correct URL if the value was clamped or filtered."""
         serialized_value = metadata.serializer(deserialized_value)
         if serialized_value == parsed_value:
             return  # No correction needed
 
-        # TODO(query-params): Remove this formatted_options handling once all selection
-        # widgets use string-based wire formats (string_value/string_array_value).
-        # For index-based widgets, don't auto-correct valid strings to indices -
-        # only correct if values were actually filtered.
-        string_option_types = ("int_value", "int_array_value", "double_array_value")
-        use_formatted_options = False
-
-        if metadata.value_type in string_option_types:
-            # Check if parsed value contained strings
-            if isinstance(parsed_value, list):
-                parsed_has_strings = any(isinstance(v, str) for v in parsed_value)
-                parsed_len = len(parsed_value)
-            else:
-                parsed_has_strings = isinstance(parsed_value, str)
-                parsed_len = 1
-
-            if parsed_has_strings:
-                serialized_len = (
-                    len(serialized_value) if isinstance(serialized_value, list) else 1
-                )
-                if serialized_len == parsed_len:
-                    return  # No filtering, keep original strings in URL
-                use_formatted_options = bool(metadata.formatted_options)
-
-        # Build corrected value, converting indices to formatted strings if needed
-        corrected_value = serialized_value
-        if use_formatted_options and metadata.formatted_options:
-            fmt_opts = metadata.formatted_options
-            if isinstance(serialized_value, list):
-                corrected_value = [
-                    fmt_opts[idx]
-                    for idx in serialized_value
-                    if isinstance(idx, int) and 0 <= idx < len(fmt_opts)
-                ]
-            elif isinstance(serialized_value, int) and 0 <= serialized_value < len(
-                fmt_opts
-            ):
-                corrected_value = fmt_opts[serialized_value]
-
         self.query_params._set_corrected_value(
-            user_key, corrected_value, metadata.value_type
+            user_key, serialized_value, metadata.value_type
         )
 
     def __contains__(self, key: str) -> bool:
