@@ -392,8 +392,7 @@ def _get_user_info() -> UserInfoType:
 
 class TokensProxy(Mapping[str, str]):
     """
-    A read-only, dict-like object for accessing exposed tokens from the\
-    identity provider.
+    A read-only, dict-like object for accessing exposed tokens from the identity provider.
 
     This class provides access to tokens that have been explicitly exposed via
     the ``expose_tokens`` setting in your authentication configuration. Tokens
@@ -527,8 +526,7 @@ class TokensProxy(Mapping[str, str]):
 
 class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
     """
-    A read-only, dict-like object for accessing information about the current\
-    user.
+    A read-only, dict-like object for accessing information about the current user.
 
     ``st.user`` is dependent on the host platform running your
     Streamlit app. If your host platform has not configured the object,
@@ -558,8 +556,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
         Whether a user is logged in. For a locally running app, this attribute
         is only available when authentication (``st.login()``) is configured in
         ``secrets.toml``. Otherwise, it does not exist.
-
-    tokens: TokensProxy
+    tokens : TokensProxy
         A read-only, dict-like object for accessing exposed tokens from the
         identity provider.
 
@@ -605,7 +602,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
             "iat":{issued_time}
             "exp":{expiration_time}
             "tokens":{}
-    }
+        }
 
     **Example 2: Microsoft's identity token**
 
@@ -646,6 +643,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
             "aio":"{opaque_string}"
             "tokens":{}
         }
+
     """
 
     def __getitem__(self, key: str) -> str | bool | TokensProxy | None:
@@ -688,6 +686,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
         -------
         Dict[str,str]
             A dictionary of the current user's information.
+
         """
         return _get_user_info()
 
