@@ -49,6 +49,7 @@ from streamlit.web.server.routes import (
     HostConfigHandler,
     RemoveSlashHandler,
     StaticFileHandler,
+    UnsafePathBlockHandler,
 )
 from streamlit.web.server.server_util import (
     get_cookie_secret,
@@ -310,7 +311,6 @@ class Server:
         self._runtime = Runtime(
             RuntimeConfig(
                 script_path=main_script_path,
-                command_line=None,
                 media_file_storage=media_file_storage,
                 uploaded_file_manager=uploaded_file_mgr,
                 cache_storage_manager=create_default_cache_storage_manager(),
@@ -370,6 +370,9 @@ class Server:
         base = config.get_option("server.baseUrlPath")
 
         routes: list[Any] = [
+            # SECURITY: Block unsafe paths (double-slash, UNC paths, etc.)
+            # before any other handler. Matches PathSecurityMiddleware in Starlette.
+            (r"^//.*$", UnsafePathBlockHandler),
             (
                 make_url_path_regex(base, STREAM_ENDPOINT),
                 BrowserWebSocketHandler,
@@ -424,7 +427,9 @@ class Server:
                         make_url_path_regex(base, SCRIPT_HEALTH_CHECK_ENDPOINT),
                         HealthHandler,
                         {
-                            "callback": lambda: self._runtime.does_script_run_without_error()
+                            "callback": lambda: (
+                                self._runtime.does_script_run_without_error()
+                            )
                         },
                     )
                 ]
