@@ -181,7 +181,7 @@ def create_streamlit_middleware() -> list[Middleware]:
     # browsers (especially WebKit) have issues with explicit identity encoding.
     middleware.append(
         Middleware(
-            MediaAwareGZipMiddleware,  # ty: ignore[invalid-argument-type]
+            MediaAwareGZipMiddleware,
             minimum_size=GZIP_MINIMUM_SIZE,
             compresslevel=GZIP_COMPRESSLEVEL,
         )
@@ -423,7 +423,6 @@ class App:
         return Runtime(
             RuntimeConfig(
                 script_path=str(script_path),
-                command_line=None,
                 media_file_storage=media_file_storage,
                 uploaded_file_manager=uploaded_file_mgr,
                 cache_storage_manager=create_default_cache_storage_manager(),
